package VMOMI::HostSystemIdentificationInfoIdentifier;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
